@@ -73,16 +73,15 @@ func MakeSSMParameterName(version, instanceType, imageFamily string) (string, er
 		return fmt.Sprintf("/aws/service/ami-windows-latest/Windows_Server-2022-English-%s-EKS_Optimized-%s/%s", windowsAmiType(imageFamily), version, fieldName), nil
 	case api.NodeImageFamilyBottlerocket:
 		return fmt.Sprintf("/aws/service/bottlerocket/aws-k8s-%s/%s/latest/%s", imageType(imageFamily, instanceType, version), instanceEC2ArchName(instanceType), fieldName), nil
-	case api.NodeImageFamilyUbuntu1804:
-		return "", &UnsupportedQueryError{msg: fmt.Sprintf("SSM Parameter lookups for %s AMIs is not supported", imageFamily)}
 	case api.NodeImageFamilyUbuntu2004,
+		api.NodeImageFamilyUbuntuPro2004,
 		api.NodeImageFamilyUbuntu2204,
 		api.NodeImageFamilyUbuntuPro2204:
 		if err := validateVersionForUbuntu(version, imageFamily); err != nil {
 			return "", err
 		}
 		eksProduct := "eks"
-		if imageFamily == api.NodeImageFamilyUbuntuPro2204 {
+		if imageFamily == api.NodeImageFamilyUbuntuPro2004 || imageFamily == api.NodeImageFamilyUbuntuPro2204 {
 			eksProduct = "eks-pro"
 		}
 		return fmt.Sprint("/aws/service/canonical/ubuntu/", eksProduct, "/", ubuntuReleaseName(imageFamily), "/", version, "/stable/current/", ubuntuArchName(instanceType), "/hvm/ebs-gp2/ami-id"), nil
@@ -116,6 +115,8 @@ func MakeManagedSSMParameterName(version string, amiType ekstypes.AMITypes) stri
 		return fmt.Sprintf("/aws/service/eks/optimized-ami/%s/%s/x86_64/neuron/recommended/release_version", version, utils.ToKebabCase(api.NodeImageFamilyAmazonLinux2023))
 	case ekstypes.AMITypesAl2023Arm64Standard:
 		return fmt.Sprintf("/aws/service/eks/optimized-ami/%s/%s/arm64/standard/recommended/release_version", version, utils.ToKebabCase(api.NodeImageFamilyAmazonLinux2023))
+	case ekstypes.AMITypesAl2023Arm64Nvidia:
+		return fmt.Sprintf("/aws/service/eks/optimized-ami/%s/%s/arm64/nvidia/recommended/release_version", version, utils.ToKebabCase(api.NodeImageFamilyAmazonLinux2023))
 	case ekstypes.AMITypesAl2X8664:
 		return makeAL2ParameterName("")
 	case ekstypes.AMITypesAl2X8664Gpu:
@@ -183,7 +184,7 @@ func windowsAmiType(imageFamily string) string {
 
 func ubuntuReleaseName(imageFamily string) string {
 	switch imageFamily {
-	case api.NodeImageFamilyUbuntu2004:
+	case api.NodeImageFamilyUbuntu2004, api.NodeImageFamilyUbuntuPro2004:
 		return "20.04"
 	case api.NodeImageFamilyUbuntu2204, api.NodeImageFamilyUbuntuPro2204:
 		return "22.04"
@@ -215,6 +216,25 @@ func validateVersionForUbuntu(version, imageFamily string) error {
 		if !supportsUbuntu {
 			return &UnsupportedQueryError{msg: fmt.Sprintf("%s requires EKS version greater or equal than %s and lower than %s", imageFamily, minVersion, maxVersion)}
 		}
+	case api.NodeImageFamilyUbuntuPro2004:
+		var err error
+		supportsUbuntu := false
+		const minVersion = api.Version1_27
+		const maxVersion = api.Version1_29
+		supportsUbuntu, err = utils.IsMinVersion(minVersion, version)
+		if err != nil {
+			return err
+		}
+		if !supportsUbuntu {
+			return &UnsupportedQueryError{msg: fmt.Sprintf("%s requires EKS version greater or equal than %s and lower than %s", imageFamily, minVersion, maxVersion)}
+		}
+		supportsUbuntu, err = utils.IsMinVersion(version, maxVersion)
+		if err != nil {
+			return err
+		}
+		if !supportsUbuntu {
+			return &UnsupportedQueryError{msg: fmt.Sprintf("%s requires EKS version greater or equal than %s and lower than %s", imageFamily, minVersion, maxVersion)}
+		}
 	case api.NodeImageFamilyUbuntu2204, api.NodeImageFamilyUbuntuPro2204:
 		var err error
 		supportsUbuntu := false
