@@ -87,6 +87,7 @@ func SetClusterConfigDefaults(cfg *ClusterConfig) {
 			cfg.RemoteNetworkConfig.IAM.Provider = &SSMProvider
 		}
 	}
+
 }
 
 // IAMServiceAccountsWithImplicitServiceAccounts adds implicitly created
@@ -121,9 +122,22 @@ func vpcCNIAddonSpecified(cfg *ClusterConfig) bool {
 }
 
 // SetNodeGroupDefaults will set defaults for a given nodegroup
-func SetNodeGroupDefaults(ng *NodeGroup, meta *ClusterMeta, controlPlaneOnOutposts bool) {
+func SetNodeGroupDefaults(ng *NodeGroup, meta *ClusterMeta, controlPlaneOnOutposts bool) error {
 	setNodeGroupBaseDefaults(ng.NodeGroupBase, meta)
 
+	// Set default AMI family depending on Kubernetes version
+	isAL2EOLVersion, _ := utils.IsMinVersion(AmazonLinux2EOLVersion, meta.Version)
+	if isAL2EOLVersion {
+		// For newer Kubernetes versions, default to AL2023
+		if ng.AMIFamily == "" {
+			ng.AMIFamily = NodeImageFamilyAmazonLinux2023
+		}
+		// Since AL2 isn't supported, throw an error if the user explicitly requested AL2
+		if ng.AMIFamily == NodeImageFamilyAmazonLinux2 {
+			return fmt.Errorf("AmazonLinux2 is not supported for Kubernetes version %s", meta.Version)
+		}
+	}
+	// Default to AL2 for Kubernetes versions prior to AmazonLinux2EOLVersion
 	if ng.AMIFamily == "" {
 		ng.AMIFamily = DefaultNodeImageFamily
 	}
@@ -139,15 +153,27 @@ func SetNodeGroupDefaults(ng *NodeGroup, meta *ClusterMeta, controlPlaneOnOutpos
 	}
 
 	setContainerRuntimeDefault(ng, meta.Version)
+	return nil
 }
 
 // SetManagedNodeGroupDefaults sets default values for a ManagedNodeGroup
-func SetManagedNodeGroupDefaults(ng *ManagedNodeGroup, meta *ClusterMeta, controlPlaneOnOutposts bool) {
+func SetManagedNodeGroupDefaults(ng *ManagedNodeGroup, meta *ClusterMeta, controlPlaneOnOutposts bool) error {
 	setNodeGroupBaseDefaults(ng.NodeGroupBase, meta)
 
 	// When using custom AMIs, we want the user to explicitly specify AMI family.
 	// Thus, we only set up default AMI family when no custom AMI is being used.
-	if ng.AMIFamily == "" && ng.AMI == "" {
+	isAL2EOLVersion, _ := utils.IsMinVersion(AmazonLinux2EOLVersion, meta.Version)
+	if ng.AMI == "" && isAL2EOLVersion {
+		// Set default AMI family depending on Kubernetes version
+		// For newer Kubernetes versions, default to AL2023
+		if ng.AMIFamily == "" {
+			ng.AMIFamily = NodeImageFamilyAmazonLinux2023
+		}
+		// Since AL2 isn't supported for this K8s version, throw an error if the user explicitly requested AL2
+		if ng.AMIFamily == NodeImageFamilyAmazonLinux2 {
+			return fmt.Errorf("AmazonLinux2 is not supported for Kubernetes version %s", meta.Version)
+		}
+	} else if ng.AMI == "" && ng.AMIFamily == "" {
 		// AL2023 is the default ami type on EKS managed nodegroups after 1.30.
 		if isMinVer, _ := utils.IsMinVersion(Version1_30, meta.Version); isMinVer {
 			ng.AMIFamily = NodeImageFamilyAmazonLinux2023
@@ -164,6 +190,8 @@ func SetManagedNodeGroupDefaults(ng *ManagedNodeGroup, meta *ClusterMeta, contro
 
 	setVolumeDefaults(ng.NodeGroupBase, controlPlaneOnOutposts, ng.LaunchTemplate)
 	setDefaultsForAdditionalVolumes(ng.NodeGroupBase, controlPlaneOnOutposts)
+
+	return nil
 }
 
 func setNodeGroupBaseDefaults(ng *NodeGroupBase, meta *ClusterMeta) {
