@@ -127,9 +127,41 @@ func (m *ManagedNodeGroupResourceSet) AddAllResources(ctx context.Context) error
 
 	if m.nodeGroup.NodeRepairConfig != nil {
 		nodeRepairConfig := &gfneks.Nodegroup_NodeRepairConfig{}
+
 		if m.nodeGroup.NodeRepairConfig.Enabled != nil {
 			nodeRepairConfig.Enabled = gfnt.NewBoolean(*m.nodeGroup.NodeRepairConfig.Enabled)
 		}
+
+		if m.nodeGroup.NodeRepairConfig.MaxUnhealthyNodeThresholdPercentage != nil {
+			nodeRepairConfig.MaxUnhealthyNodeThresholdPercentage = gfnt.NewInteger(*m.nodeGroup.NodeRepairConfig.MaxUnhealthyNodeThresholdPercentage)
+		}
+
+		if m.nodeGroup.NodeRepairConfig.MaxUnhealthyNodeThresholdCount != nil {
+			nodeRepairConfig.MaxUnhealthyNodeThresholdCount = gfnt.NewInteger(*m.nodeGroup.NodeRepairConfig.MaxUnhealthyNodeThresholdCount)
+		}
+
+		if m.nodeGroup.NodeRepairConfig.MaxParallelNodesRepairedPercentage != nil {
+			nodeRepairConfig.MaxParallelNodesRepairedPercentage = gfnt.NewInteger(*m.nodeGroup.NodeRepairConfig.MaxParallelNodesRepairedPercentage)
+		}
+
+		if m.nodeGroup.NodeRepairConfig.MaxParallelNodesRepairedCount != nil {
+			nodeRepairConfig.MaxParallelNodesRepairedCount = gfnt.NewInteger(*m.nodeGroup.NodeRepairConfig.MaxParallelNodesRepairedCount)
+		}
+
+		if len(m.nodeGroup.NodeRepairConfig.NodeRepairConfigOverrides) > 0 {
+			var overrides []gfneks.Nodegroup_NodeRepairConfigOverride
+			for _, override := range m.nodeGroup.NodeRepairConfig.NodeRepairConfigOverrides {
+				cfnOverride := gfneks.Nodegroup_NodeRepairConfigOverride{
+					NodeMonitoringCondition: gfnt.NewString(override.NodeMonitoringCondition),
+					NodeUnhealthyReason:     gfnt.NewString(override.NodeUnhealthyReason),
+					MinRepairWaitTimeMins:   gfnt.NewInteger(override.MinRepairWaitTimeMins),
+					RepairAction:            gfnt.NewString(override.RepairAction),
+				}
+				overrides = append(overrides, cfnOverride)
+			}
+			nodeRepairConfig.NodeRepairConfigOverrides = overrides
+		}
+
 		managedResource.NodeRepairConfig = nodeRepairConfig
 	}
 
