@@ -41,6 +41,7 @@ func loadBalancerControllerStatements() []cft.MapOfInterfaces {
 				"ec2:DescribeCoipPools",
 				"ec2:GetSecurityGroupsForVpc",
 				"ec2:DescribeIpamPools",
+				"ec2:DescribeRouteTables",
 				"elasticloadbalancing:DescribeLoadBalancers",
 				"elasticloadbalancing:DescribeLoadBalancerAttributes",
 				"elasticloadbalancing:DescribeListeners",
@@ -368,142 +369,6 @@ func appMeshStatements(appendAction string) []cft.MapOfInterfaces {
 	}
 }
 
-func ebsStatements() []cft.MapOfInterfaces {
-	return []cft.MapOfInterfaces{
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:CreateSnapshot",
-				"ec2:AttachVolume",
-				"ec2:DetachVolume",
-				"ec2:ModifyVolume",
-				"ec2:DescribeAvailabilityZones",
-				"ec2:DescribeInstances",
-				"ec2:DescribeSnapshots",
-				"ec2:DescribeTags",
-				"ec2:DescribeVolumes",
-				"ec2:DescribeVolumesModifications",
-			},
-			"Resource": "*",
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:CreateTags",
-			},
-			"Resource": []*gfnt.Value{
-				addARNPartitionPrefix("ec2:*:*:volume/*"),
-				addARNPartitionPrefix("ec2:*:*:snapshot/*"),
-			},
-			"Condition": cft.MapOfInterfaces{
-				"StringEquals": cft.MapOfInterfaces{
-					"ec2:CreateAction": []string{
-						"CreateVolume",
-						"CreateSnapshot",
-					},
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:DeleteTags",
-			},
-			"Resource": []*gfnt.Value{
-				addARNPartitionPrefix("ec2:*:*:volume/*"),
-				addARNPartitionPrefix("ec2:*:*:snapshot/*"),
-			},
-		},
-		{
-			"Effect": "Allow",
-
-			"Action": []string{
-
-				"ec2:CreateVolume",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"aws:RequestTag/ebs.csi.aws.com/cluster": "true",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:CreateVolume",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"aws:RequestTag/CSIVolumeName": "*",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:DeleteVolume",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"ec2:ResourceTag/ebs.csi.aws.com/cluster": "true",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-
-			"Action": []string{
-				"ec2:DeleteVolume",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"ec2:ResourceTag/CSIVolumeName": "*",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:DeleteVolume",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"ec2:ResourceTag/kubernetes.io/created-for/pvc/name": "*",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:DeleteSnapshot",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"ec2:ResourceTag/CSIVolumeSnapshotName": "*",
-				},
-			},
-		},
-		{
-			"Effect": "Allow",
-			"Action": []string{
-				"ec2:DeleteSnapshot",
-			},
-			"Resource": "*",
-			"Condition": cft.MapOfInterfaces{
-				"StringLike": cft.MapOfInterfaces{
-					"ec2:ResourceTag/ebs.csi.aws.com/cluster": "true",
-				},
-			},
-		},
-	}
-}
-
 func serviceLinkRoleStatements() []cft.MapOfInterfaces {
 	return []cft.MapOfInterfaces{
 		{
