@@ -2,16 +2,15 @@ package credentials_test
 
 import (
 	"context"
+	"errors"
 	"os"
 	"path"
 	"time"
 
 	"github.com/aws/aws-sdk-go-v2/aws"
-	awscredentials "github.com/aws/aws-sdk-go/aws/credentials"
 	. "github.com/onsi/ginkgo/v2"
 
 	. "github.com/onsi/gomega"
-	"github.com/pkg/errors"
 	"github.com/spf13/afero"
 	"gopkg.in/yaml.v2"
 
@@ -45,8 +44,7 @@ var _ = Describe("FileCacheV2", func() {
 	}
 
 	type cachedCredential struct {
-		Credential awscredentials.Value
-		Expiration time.Time
+		Credential aws.Credentials
 	}
 
 	makeFlock := func(_ string) credentials.Flock {
@@ -86,6 +84,7 @@ var _ = Describe("FileCacheV2", func() {
 			Expect(os.IsNotExist(err)).To(BeTrue())
 			return
 		}
+
 		Expect(err).NotTo(HaveOccurred())
 		Expect(string(data)).To(Equal(e.expectedCacheData))
 	},
@@ -108,8 +107,10 @@ var _ = Describe("FileCacheV2", func() {
       accesskeyid: k123
       secretaccesskey: s123
       sessiontoken: t123
-      providername: eksctl-test
-    expiration: 0001-01-01T00:00:00Z
+      source: eksctl-test
+      canexpire: true
+      expires: 0001-01-01T00:00:00Z
+      accountid: ""
 `,
 		}),
 
@@ -122,13 +123,14 @@ var _ = Describe("FileCacheV2", func() {
 				data, err := yaml.Marshal(map[string]map[string]cachedCredential{
 					"profiles": {
 						"test": {
-							Credential: awscredentials.Value{
+							Credential: aws.Credentials{
 								AccessKeyID:     "k123",
 								SecretAccessKey: "s123",
 								SessionToken:    "t123",
-								ProviderName:    "eksctl-test",
+								CanExpire:       true,
+								Source:          "eksctl-test",
+								Expires:         time.Date(9999, 1, 1, 0, 0, 0, 0, time.UTC),
 							},
-							Expiration: time.Date(9999, 1, 1, 0, 0, 0, 0, time.UTC),
 						},
 					},
 				})
@@ -149,8 +151,10 @@ var _ = Describe("FileCacheV2", func() {
       accesskeyid: k123
       secretaccesskey: s123
       sessiontoken: t123
-      providername: eksctl-test
-    expiration: 9999-01-01T00:00:00Z
+      source: eksctl-test
+      canexpire: true
+      expires: 9999-01-01T00:00:00Z
+      accountid: ""
 `,
 		}),
 
@@ -163,13 +167,13 @@ var _ = Describe("FileCacheV2", func() {
 				data, err := yaml.Marshal(map[string]map[string]cachedCredential{
 					"profiles": {
 						"test": {
-							Credential: awscredentials.Value{
+							Credential: aws.Credentials{
 								AccessKeyID:     "k123",
 								SecretAccessKey: "s123",
 								SessionToken:    "t123",
-								ProviderName:    "eksctl-test",
+								Source:          "eksctl-test",
+								Expires:         time.Time{},
 							},
-							Expiration: time.Time{},
 						},
 					},
 				})
@@ -197,8 +201,10 @@ var _ = Describe("FileCacheV2", func() {
       accesskeyid: a567
       secretaccesskey: s567
       sessiontoken: t567
-      providername: eksctl-test
-    expiration: 9999-01-01T00:00:00Z
+      source: eksctl-test
+      canexpire: true
+      expires: 9999-01-01T00:00:00Z
+      accountid: ""
 `,
 		}),
 
@@ -211,13 +217,13 @@ var _ = Describe("FileCacheV2", func() {
 				data, err := yaml.Marshal(map[string]map[string]cachedCredential{
 					"profiles": {
 						"eksctl": {
-							Credential: awscredentials.Value{
+							Credential: aws.Credentials{
 								AccessKeyID:     "a123",
 								SecretAccessKey: "s123",
 								SessionToken:    "t123",
-								ProviderName:    "eksctl-test",
+								Source:          "eksctl-test",
+								Expires:         time.Date(9999, 1, 1, 0, 0, 0, 0, time.UTC),
 							},
-							Expiration: time.Date(9999, 1, 1, 0, 0, 0, 0, time.UTC),
 						},
 					},
 				})
@@ -244,8 +250,10 @@ var _ = Describe("FileCacheV2", func() {
       accesskeyid: a123
       secretaccesskey: s123
       sessiontoken: t123
-      providername: eksctl-test
-    expiration: 9999-01-01T00:00:00Z
+      source: eksctl-test
+      canexpire: false
+      expires: 9999-01-01T00:00:00Z
+      accountid: ""
 `,
 		}),
 
