@@ -16,21 +16,6 @@ var _ = Describe("release tests", func() {
 		version.PreReleaseID = "dev"
 	})
 
-	It("produces a release without a pre-release id", func() {
-		v, p := prepareRelease()
-
-		Expect(v).To(Equal("0.5.0"))
-		Expect(p).To(BeEmpty())
-	})
-
-	It("produces the correct release for 2 digit minor versions", func() {
-		version.Version = "0.25.0"
-		v, p := prepareRelease()
-
-		Expect(v).To(Equal("0.25.0"))
-		Expect(p).To(BeEmpty())
-	})
-
 	It("increases minor version for the next development iteration from a release", func() {
 		version.PreReleaseID = ""
 
@@ -49,30 +34,14 @@ var _ = Describe("release tests", func() {
 		Expect(p).To(Equal("dev"))
 	})
 
-	It("produces the correct default release candidate from dev", func() {
-		version.PreReleaseID = "dev"
-
-		v, p := prepareReleaseCandidate()
-
-		Expect(v).To(Equal("0.5.0"))
-		Expect(p).To(Equal("rc.0"))
-	})
-	It("produces the correct default release candidate from release", func() {
-		version.PreReleaseID = ""
-
-		v, p := prepareReleaseCandidate()
-
-		Expect(v).To(Equal("0.5.0"))
-		Expect(p).To(Equal("rc.0"))
-	})
-
-	It("produces next release candidate", func() {
-		version.PreReleaseID = "rc.1"
-
-		v, p := prepareReleaseCandidate()
-
-		Expect(v).To(Equal("0.5.0"))
-		Expect(p).To(Equal("rc.2"))
-	})
+	DescribeTable("gets the next pre-release ID", func(releaseVersion, expectedPreReleaseID string) {
+		preReleaseID, err := nextPreReleaseID(releaseVersion)
+		Expect(err).NotTo(HaveOccurred())
+		Expect(preReleaseID).To(Equal(expectedPreReleaseID))
+	},
+		Entry("no previous RC", "", "rc.0"),
+		Entry("rc.0 exists", "0.100.0-rc.0", "rc.1"),
+		Entry("rc.5 exists", "v0.100.0-rc.5", "rc.6"),
+	)
 
 })
